"use client";

import { Link } from "@/i18n/routing";
import { add } from "@/servers/actions/favorite-action";
import { usePaginatedProducts } from "@/servers/data/use-product";
import Cookies from "js-cookie";
import { Loader2 } from "lucide-react"; // Using lucide-react for icons
import { useLocale, useTranslations } from "next-intl";
import React, { useState } from "react";
import { toast } from "sonner";
import FavoriteCard from "./favorite-card";
const ITEMS_PER_PAGE = 10; // Number of products per page

// The main Favorites Page component
const FavoritesList: React.FC = () => {
	const t = useTranslations();
	const locale = useLocale();

	const [loadingProductIds, setLoadingProductIds] = useState<Record<string, boolean>>({});
	const [currentPage, setCurrentPage] = useState(1); // State for current page

	const {
		products,
		isLoading,
		isFetching,
		refetch,
	} = usePaginatedProducts(
		currentPage,
		ITEMS_PER_PAGE,
		{
			is_favorite: true
		}
	);

	console.log("products: ", products);

	const handleRemoveFavorite = async (id: any) => {
		const _session = Cookies.get("__t");

		if (!_session) {
			toast.error(t("Please login to add to cart"));
			return;
		}

		// Set loading state for this specific product
		setLoadingProductIds(prev => ({ ...prev, [id]: true }));

		try {
			const result = await add(id);
			if (result?.success) {
				toast.success(t("Product removed from favorite"), {
					style: { backgroundColor: "green", color: "white" },
				});

				await refetch();
			} else {
				toast.error(t(result?.message?.replace(".", "")));
			}
		} catch (error: any) {
			console.log("error: ", error);
			toast.error("Something went wrong");
		} finally {
			// Clear loading state for this specific product
			setLoadingProductIds(prev => ({ ...prev, [id]: false }));
		}
	};

	return (
		<div className="container mx-auto px-4 py-8 font-sans">
			<h1 className="text-3xl font-bold mb-8 text-center md:text-right">{t("Your Favorite Products")}</h1>

			{isLoading ? (
				<div className="flex justify-center items-center h-screen">
					<Loader2 className="h-10 w-10 animate-spin" />
				</div>
			) : products?.length === 0 ? (
				<div className="text-center text-gray-500 py-10">
					<p className="text-xl mb-4">{t("No products found")}</p>
				</div>
			) : (
				// Use flex column for list layout with spacing between items
				<div className="flex flex-col space-y-4">
					{products?.map((product: any) => (
						// Each favorite item is now a Card displayed as a row on medium screens and up
						<Link href={`/products/${product.product_slug}` as any} key={product.id}>
							<FavoriteCard key={product.id}
								product={product}
								removeFavorite={handleRemoveFavorite}
								loadingProductIds={loadingProductIds} />
						</Link>
					))}
				</div>
			)}
		</div>
	);
};

export default FavoritesList;
